﻿#pragma strict

/*
MUSIC MANAGER by Luke Molnar
This script allows you to add music to your scene with ease.

To begin, if the first AudioClip is an Intro or Lead-In track, be sure to check the "Is There An Intro" box.

If there is an Intro, you must then set the cut in time, which is the time the next audio file will start playing at. This allows for overlapping of AudioClips.

Next, set the number of AudioClips you will be using with the "Clips" variable. 

Note, if you would like the tracks to play at random, select the "Random" option.

Note, this script uses the Player Preference "musicVolume" to set the volume of the music.
*/

public var isThereAnIntro : boolean = false;
public var cutIntoIntroTime : float;
public var randomiseClips : boolean = false;
public var clips = new AudioClip[2];
private var pastIntro : boolean = false;
private var clipCounter : int = 0;
private var nextEventTime : double;
private var flip = 0;
private var audioSources = new AudioSource[2];
private var running = false;

function Start()
{
	for(var i = 0; i < 2; i++)
	{
		var child:GameObject = new GameObject("MusicPlayer");
		child.transform.parent = gameObject.transform;
		audioSources[i] = child.AddComponent("AudioSource");
	}
	nextEventTime = AudioSettings.dspTime + 2.0;
	running = true;
	
	if (!isThereAnIntro)
		clipCounter = clips.Length;
}

function Update()
{
	if(!running)
		return;
	var time = AudioSettings.dspTime;
	if(time + 1.0 > nextEventTime)
	{
		//If there is an intro file and it hasn't been played yet, then play it.
		if (isThereAnIntro && !pastIntro)
		{
			audioSources[flip].clip = clips[0];
			pastIntro = true;
		}
		else if (isThereAnIntro && pastIntro)
		{
			//Play all songs in list except for first.
			if (clipCounter + 1 > clips.Length)
			{
				clipCounter = 1;
				audioSources[flip].clip = clips[clipCounter];
			}
			else
			{
				clipCounter += 1;
				audioSources[flip].clip = clips[clipCounter];
			}
		}
		else if (!isThereAnIntro)
		{
			//Play all clips in list.
			if (clipCounter + 1 > clips.Length)
			{
				clipCounter = 0;
				audioSources[flip].clip = clips[clipCounter];
			}
			else
			{
				clipCounter += 1;
				audioSources[flip].clip = clips[clipCounter];
			}
		}
		
		//Audio channel and start time selector.
		if (isThereAnIntro && clipCounter == 0)
		{
			audioSources[flip].PlayScheduled(nextEventTime);
			nextEventTime += cutIntoIntroTime;
			flip = 1 - flip;
		}
		else
		{
			audioSources[flip].PlayScheduled(nextEventTime);
			nextEventTime += clips[clipCounter].length;
			flip = 1 - flip;
		}
	}
	
	//Set Music Volume.
	if (PlayerPrefs.GetFloat("musicVolume") < 0 || PlayerPrefs.GetFloat("musicVolume") > 1)
		Debug.Log("MUSIC MANAGER ERROR: There is no variable called musicVolume with a value of 0 to 1 in the Player Preferences!");
	else
	{
		audioSources[0].audio.volume = PlayerPrefs.GetFloat("musicVolume");
		audioSources[1].audio.volume = PlayerPrefs.GetFloat("musicVolume");
		//Debug.Log(PlayerPrefs.GetFloat("musicVolume"));
	}
	
	//randomiseClips
	if (randomiseClips)
		Debug.Log("MUSIC MANAGER ERROR: The Randomise feature currently does not work.");
}